import { useEffect, useMemo, useState } from 'react'
import Taro from '@tarojs/taro'
import { View } from '@tarojs/components'
import Divider from '@/components/Divider'
import dayjs from 'dayjs'
import './style.less'

export default (props) => {
  const [height, setHeight] = useState(40)
  const today = useMemo(() => dayjs().format('YYYY-MM-DD'), [])

  const footerStyle = useMemo(() => {
    return {
      height: `${height}px`
    }
  }, [height])

  useEffect(() => {
    Taro.nextTick(() => {
      const query = Taro.createSelectorQuery();
      query.select('.index-footer').boundingClientRect((rect) => {
        const { top } = rect || {}
        if (!top) return;
  
        const { safeArea } = Taro.getSystemInfoSync()
  
        // 4 是随便给的一个允许误差范围
        setHeight(safeArea.height - Math.ceil(top) - 4);
      }).exec()
    })
  }, [])

  return (
    <View className='index-footer' style={footerStyle}>
      <View>
        <View className='footer-time'>{today}</View>
        <View className='footer-copyright'>
          <Divider>
            南京云致提供技术支持
          </Divider>
        </View>
      </View>
    </View>
  )
}
