import { View, Text, Image } from '@tarojs/components'
import { useEffect, useMemo, useRef, useState } from 'react'
import { SwipeCell, Dialog, Tabs, Tab } from "@antmjs/vantui";
import Taro from '@tarojs/taro';
import BarCode from '@/components/barcode'
import Back from './components/Back';
import Main from './components/Main';
import Header from './components/Header';
import QRBox from './components/QRBox';
import QRItem from './components/QRItem';
import Footer from './components/Footer';
import { useModel } from '@/store';
import { getBarcode } from '@/services/user';

import './style.less'

const tabTitleStyle = {
  fontSize: '36rpx'
}

export default (props) => {
  const { person, user } = useModel('userData')
  const [barData, setBarData] = useState({})
  const [idCardVisible, setIdCardVisible] = useState(false)
  const goUserInfo = () => {
    Taro.navigateTo({
      url: '/pages/setUserInfo/index'
    })
  }

  const handleShowEditor = () => {
    setIdCardVisible(false)
    goUserInfo()
  }

  useEffect(() => {
    if (person && person.personId) {
      getBarcode(person.personId).then((res) => {
        if (typeof res === 'string') {
          const resp = JSON.parse(res) || {}
          setBarData(resp)
        } else {
          setBarData(res || {})
        }
      })
    }

    if (user && user.userId) {
      if (!person || !person.idNo) {
        setIdCardVisible(true)
      } else {
        setIdCardVisible(false)
      }
    }
  }, [person, user])

  return (
    <View className='index-page'>
      <Back />
      <Main>
        <Header person={person} onEdit={goUserInfo} />
        <QRBox style={{ marginTop: '1.6em' }}>
          <Tabs lineHeight={2} lineWidth={120} color='#03737b' titleActiveColor='#03737b'>
            <Tab title='条码' titleStyle={tabTitleStyle}>
              <QRItem barData={barData}>
                <BarCode ratio={0.7} height={80} code={barData.barcode} />
              </QRItem>
            </Tab>
            <Tab title='身份码' titleStyle={tabTitleStyle}>
              <QRItem>
                <BarCode ratio={0.7} height={80} code={person?.idNo} />
              </QRItem>
            </Tab>
          </Tabs>
        </QRBox>
        <Dialog title='提示' message='未添加个人信息' show={idCardVisible} onConfirm={handleShowEditor} />
      </Main>
      <Footer />
    </View>
  )
}




